import { IColor, IColorPalette, IRgbColorValue } from "@gooddata/sdk-model";
import { CalculationType } from "../../interfaces/index.js";
/**
 * @internal
 */
interface ICalculationDefaultValue {
    defaultLabelKeys: IDefaultLabelKeys;
    defaultFormat: string;
    defaultSubFormat?: string;
}
/**
 * @internal
 */
interface IDefaultLabelKeys {
    nonConditionalKey: string;
    positiveKey?: string;
    negativeKey?: string;
    equalsKey?: string;
}
/**
 * @internal
 */
declare enum ComparisonColorType {
    POSITIVE = "positive",
    NEGATIVE = "negative",
    EQUALS = "equals"
}
/**
 * @internal
 */
declare const CALCULATION_VALUES_DEFAULT: {
    [key in CalculationType]?: ICalculationDefaultValue;
};
/**
 * @internal
 */
declare const DEFAULT_COMPARISON_PALETTE: IColorPalette;
/**
 * Get comparison format
 *
 * @remarks
 * We offer the option to inherit the format with a null value. When the provided format is null,
 * it indicates the user's preference to utilize the inherit format.
 *
 * If the format is undefined, the default format will be used.
 *
 * @internal
 */
declare const getComparisonFormat: (providedFormat: string, defaultFormat: string) => string;
/**
 * Method to retrieve default values corresponding to the calculation type.
 *
 * @internal
 */
declare const getCalculationValuesDefault: (calculationType?: CalculationType) => ICalculationDefaultValue;
/**
 * @internal
 */
declare const getComparisonRgbColor: (color: IColor, colorType: ComparisonColorType, colorPalette?: IColorPalette) => IRgbColorValue;
/**
 * NOTE: exported to satisfy sdk-ui-ext; is internal, must not be used outside of SDK; will disapppear.
 */
export { CALCULATION_VALUES_DEFAULT, DEFAULT_COMPARISON_PALETTE, getCalculationValuesDefault, getComparisonFormat, getComparisonRgbColor, ICalculationDefaultValue, IDefaultLabelKeys, ComparisonColorType, };
//# sourceMappingURL=headlineHelper.d.ts.map